@@ -9,15 +9,30 @@ logging.getLogger('botocore').setLevel(logging.CRITICAL)
 boto3.set_stream_logger(level=logging.INFO)
 
 
+def get_client_and_resource(aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None):
+    session = boto3.Session(
+        aws_access_key_id=aws_access_key_id,
+        aws_secret_access_key=aws_secret_access_key,
+        aws_session_token=aws_session_token)
+    return session.client('s3'), session.resource('s3')
+
+
 class S3Storage(CloudStorage):
 
     description = 'Amazon S3'
 
+    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None, **kwargs):
+        self.aws_access_key_id = aws_access_key_id
+        self.aws_secret_access_key = aws_secret_access_key
+        self.aws_session_token = aws_session_token
+        
+        super(S3Storage, self).__init__(**kwargs)
+
     def _get_client(self):
-        s3 = boto3.resource('s3')
+        client, s3 = get_client_and_resource(self.aws_access_key_id, self.aws_secret_access_key, self.aws_session_token)
         return {
             's3': s3,
-            'client': boto3.client('s3'),
+            'client': client,
             'bucket': s3.Bucket(self.path)
         }
 
@@ -69,6 +84,10 @@ class S3CompletionsStorageForm(BaseForm):
 class S3CompletionsStorage(S3Storage):
 
     form = S3CompletionsStorageForm
+    
+    def __init__(self, use_blob_urls=False, regex='.*', **kwargs):
+        """Completion Storages are unfiltered JSON storages"""
+        super(S3CompletionsStorage, self).__init__(use_blob_urls=False, regex='.*', **kwargs)
 
     def _validate_object(self, key):
         value = self._get_value(key)
